%{CPP_TEMPLATE}

#include "pref.h"

#include <klocale.h>

#include <tqlayout.h>
#include <tqlabel.h>

%{APPNAME}Preferences::%{APPNAME}Preferences()
    : KDialogBase(TreeList, i18n("%{APPNAME} Preferences"),
                  Help|Default|Ok|Apply|Cancel, Ok)
{
    // this is the base class for your preferences dialog.  it is now
    // a Treelist dialog.. but there are a number of other
    // possibilities (including Tab, Swallow, and just Plain)
    TQFrame *frame;
    frame = addPage(i18n("First Page"), i18n("Page One Options"));
    m_pageOne = new %{APPNAME}PrefPageOne(frame);

    frame = addPage(i18n("Second Page"), i18n("Page Two Options"));
    m_pageTwo = new %{APPNAME}PrefPageTwo(frame);
}

%{APPNAME}PrefPageOne::%{APPNAME}PrefPageOne(TQWidget *parent)
    : TQFrame(parent)
{
    TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
    tqlayout->setAutoAdd(true);

    new TQLabel(i18n("Add something here"), this);
}

%{APPNAME}PrefPageTwo::%{APPNAME}PrefPageTwo(TQWidget *parent)
    : TQFrame(parent)
{
    TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
    tqlayout->setAutoAdd(true);

    new TQLabel(i18n("Add something here"), this);
}
#include "pref.moc"
